@@ -6,7 +6,7 @@ from cnvrg.modules.endpoint import Endpoint
 from cnvrg.modules.dataset import Dataset
 from cnvrg.modules.flow import Flow
 from cnvrg.modules.flow_version import FlowVersion
-from cnvrg.modules.file_uploader import FileUploader
+from cnvrg.modules.storage.file_uploader import FileUploader
 from cnvrg.modules.cnvrg_me import Cnvrg
 from cnvrg.modules.data_connector import *
 from cnvrg.version import VERSION
