@@ -4,7 +4,7 @@ import mimetypes
 
 from cnvrg.helpers.apis_helper import post as apis_post, get as apis_get, credentials
 from cnvrg.modules.cnvrg_files import CnvrgFiles
-from cnvrg.modules.errors import CnvrgError
+from cnvrg.modules.errors import CnvrgError, APINotFound
 from cnvrg.helpers.url_builder_helper import url_join
 from cnvrg.helpers.error_catcher import suppress_exception
 from cnvrg.modules.storage.file_uploader import FileUploader
@@ -45,42 +45,41 @@ class Project(CnvrgFiles):
         result = json.loads(resp.get("result"))
         return result.get("git")
 
-    def put_files(self, files=None, path=None, pattern="*", message="SDK Commit", depth=False):
-        if not files and not path:
+    def put_files(self, paths=None, pattern="*", message="SDK Commit", depth=False, payload=None, prefix=None):
+        if not paths:
             raise CnvrgError("Please send files or path")
 
-        commit_sha1 = self.start_commit_new(message=message)
-
         full_paths = []
 
-        if path:
-            full_paths = FileUploader.get_files_and_dirs_recursive(root_dir=path, regex=pattern)
-        else:
-            for file in files:
-                is_absolute = os.path.isabs(file)
-                is_dir = os.path.isdir(file)
-                is_file = os.path.isfile(file)
-                if not is_file and not is_dir:
-                    print("{} not exists skipping it".format(file))
-                    try:
-                        files.remove(file)
-                    except ValueError as e:
-                        pass
-                trees = FileUploader.get_recursive_tree(file, is_absolute, is_dir, depth)
+        for p in paths:
+            is_absolute = os.path.isabs(p)
+            is_dir = os.path.isdir(p)
+            is_file = os.path.isfile(p)
+
+            if is_dir:
+                full_paths += FileUploader.get_files_and_dirs_recursive(root_dir=p, regex=pattern)
+            elif is_file:
+                trees = FileUploader.get_recursive_tree(p, is_absolute, is_dir, depth)
                 full_paths += trees
                 if not is_absolute:
                     if is_dir:
-                        file_path = "{}/".format(file)
+                        file_path = "{}/".format(p)
                     else:
-                        file_path = file
+                        file_path = p
                     full_paths.append(file_path)
 
                 if is_absolute and depth:
                     if is_dir:
-                        file_path = "{}/".format(file)
+                        file_path = "{}/".format(p)
                     else:
-                        file_path = file
+                        file_path = p
                     full_paths.append(file_path)
+            else:
+                print("{} not exists skipping it".format(p))
+                try:
+                    paths.remove(p)
+                except ValueError:
+                    pass
 
         full_paths_set = set(full_paths) - {"./", ".", "/", "//"}
         unique_full_paths = list(full_paths_set)
@@ -88,9 +87,10 @@ class Project(CnvrgFiles):
         if not unique_full_paths:
             print("Nothing to upload\nAborting")
             exit(0)
-        print(unique_full_paths)
+
         fu = FileUploader(self)
-        fu.upload_multiple_files(self, files=unique_full_paths, local_dir=path, commit_sha1=commit_sha1)
+        commit_sha1 = self.start_commit_new(message=message, payload=payload)
+        fu.upload_multiple_files(self, files=unique_full_paths, commit_sha1=commit_sha1, prefix=prefix)
         resp = self.end_commit_new(commit_sha1=commit_sha1)
 
         if resp.get("status") == 200:
@@ -98,12 +98,18 @@ class Project(CnvrgFiles):
         else:
             raise CnvrgError("Couldn’t create commit")
 
-    def start_commit_new(self, message="SDK Commit"):
+    def start_commit_new(self, message="SDK Commit", payload=None):
+        if payload is None:
+            payload = {}
+
         resp = apis_helper.post_v2(url_join(self.owner, "files", "start_commit"), data={
             "fileable_type": "Project",
             "fileable_slug": self.slug,
-            "message": message
+            "message": message,
+            **payload
         })
+        if resp.status_code == 404:
+            raise APINotFound("API Not Found")
         return resp.json().get("result").get("commit_sha1")
 
     def end_commit_new(self, commit_sha1):
@@ -115,18 +121,6 @@ class Project(CnvrgFiles):
 
         return resp.json()
 
-    def download_file(self, files):
-        pass
-        # resp = apis_helper.post_v2(url_join(self.owner, "files", "get_blob_info"), data={
-        #     "fileable_type": "Project",
-        #     "fileable_slug": self.slug,
-        #     "files": files
-        # })
-        # blobs = resp.json().get("blobs")
-        # print(blobs)
-        # fu = FileUploader(self)
-        # fu.download_multiple_files(blobs)
-
     @staticmethod
     @suppress_exception
     def list(owner=None):
